%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                   File: dokdok.cls                  %
%                   Version: 1.0                      %
%                   Date: 16 Mar 2018                 %
%                                                     %
%     This class file is provided for authors         %
%     submitting to the DoKDoK conference on          %
%       optics, dokdok.org.                           %
%                                                     %
%     Copyright 2018 DoKDoK organizing team           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{dokdok}[16/03/2018, v1.0]
\AtEndOfClass{\RequirePackage{microtype}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{extarticle}}
\ProcessOptions*
\LoadClass{extarticle}

\RequirePackage{mathtools} % loads amsmath
\RequirePackage{unicode-math} % loads fontspec
\defaultfontfeatures{Ligatures=TeX}
% Font selection - The idea is to have the same fonts in the Latex and in the Word template.
% Our first idea was to use freely available OTF fonts that are shipped with Latex and embed them 
% into the Word template. It turned out, however, that this simply does not work. Word offers this
% functionality and it _should_ work but in fact it does not. Probably this feature is buggy and
% Micro$oft has never bothered to fix it.
% The other way around is to use XeLaTeX/LuaLaTeX which can use the Microsoft fonts. When they are not
% installed on the system of the user, the template falls back to compatible fonts and they will
% be replaced when we compile the abstract.
% SERIF FONT
\IfFontExistsTF{Palatino Linotype}{% use Palatino if it is installed
\setmainfont{Palatino Linotype}%
}{%
\setmainfont[% loads Tex Gyre Pagella as serif
    Extension=.otf,
    UprightFont=*-regular,
    BoldFont=*-bold.otf,
    ItalicFont=*-italic.otf,
    BoldItalicFont=*-bolditalic.otf
]{texgyrepagella}
}
% SANS-SERIF FONT
\IfFontExistsTF{Calibri}{% use it
\setsansfont{Calibri}
}{% otherwise fall back to Carlito which is metric compatible
\setsansfont[
	Extension=.ttf,
	UprightFont=*-Regular,
	BoldFont=*-Bold,
	ItalicFont=*-Italic,
	BoldItalicFont=*-BoldItalic
]{Carlito}
}
% MATH FONT
\IfFontExistsTF{Cambria Math}{% if Cambria Math exists
\setmathfont{Cambria Math}% use it
}{% otherwise fall back to an alternative
\setmathfont{texgyrepagella-math.otf}%
}

\RequirePackage{polyglossia} % xelatex replacement of babel
\setdefaultlanguage[variant=american]{english}
\RequirePackage{url}
%\RequirePackage[colorlinks=true, allcolors=blue]{hyperref}

\newcommand{\headerfont}{\normalfont\sffamily\fontsize{7}{9} \selectfont}
\newcommand{\titlefont}{\normalfont\sffamily\bfseries\fontsize{22}{25}\selectfont}
\renewcommand\UrlFont{\color{color1}\sffamily}
\newcommand{\absfont}{\normalfont\rmfamily\bfseries\fontsize{11}{14}\selectfont}

% Author and affiliation
\RequirePackage{authblk}
\setlength{\affilsep}{1em}
\renewcommand\Authfont{\color{color2}\normalfont\sffamily\bfseries\scshape\fontsize{15}{17}\selectfont}
\renewcommand\Affilfont{\color{color0}\normalfont\sffamily\itshape\fontsize{9}{11}\selectfont}
% patch authblk to use the correct fonts
\renewcommand\AB@authnote[1]{\textsuperscript{\normalfont\sffamily\fontsize{10}{12}\selectfont{#1}}}
\renewcommand\AB@affilnote[1]{\textsuperscript{\normalfont\sffamily\fontsize{9}{11}\selectfont{#1}}}


% Graphics, tables and other formatting
\RequirePackage{graphicx,xcolor,float}
\RequirePackage{colortbl}
\RequirePackage{booktabs}
\RequirePackage{changepage}
\RequirePackage[left=2cm,%
right=2cm,%
top=1.4cm,%
bottom=1.5cm,%
headheight=0.82cm,%
headsep=0.25cm,%
a4paper]{geometry}%
\RequirePackage[labelfont={bf,sf},%
labelsep=period,%
figurename=Fig.,%
singlelinecheck=off,%
justification=RaggedRight]{caption}
\setlength{\columnsep}{24pt} % Distance between the two columns of text
\setlength{\parindent}{12pt} % Paragraph indent
\setlength{\textfloatsep}{10pt plus 1.0pt minus 2.0pt} % Distance between a figure and the text
\setlength{\intextsep}{10pt plus 1.0pt minus 2.0pt}
% less space before equations
\setlength{\abovedisplayskip}{5pt plus 1pt minus 2pt}
\setlength{\belowdisplayskip}{0pt}
\setlength{\abovedisplayshortskip}{1pt plus 0.5pt minus 1pt}
\setlength{\belowdisplayshortskip}{0pt}
% Set document color scheme
\definecolor{color0}{RGB}{0,0,0} % Base
\definecolor{color1}{RGB}{59,90,198} % author email
\definecolor{color2}{RGB}{0,0,0} %{55,113,200} Header, authors, table lines = DoKDoK blue

% Bibliography    
\RequirePackage[numbers,sort&compress]{natbib}
\setlength{\bibsep}{0.0pt}
\renewcommand{\bibsection}{{\hfil\rule{0.75\linewidth}{0.75pt}\hfil
}}
\renewcommand*{\bibfont}{\small}
% \bibliographystyle{dokdok}


% Table style
\arrayrulecolor{color2} % Set the color of the horizontal rules
\renewcommand{\arraystretch}{1.5} % Increased line spacing
\captionsetup[table]{position=below} % Reduce spacing below caption

% Headers and footers
\RequirePackage{fancyhdr}  % custom headers/footers
\RequirePackage{lastpage}  % Number of pages in the document
\pagestyle{fancy}          % Enables the custom headers/footers
% Headers
\lhead{\includegraphics[width=\textwidth]{header}}
\rhead{}
\chead{}
% Footers
\lfoot{}%
\cfoot{}%
\rfoot{}%
\renewcommand{\headrulewidth}{0pt}% % No header rule
\renewcommand{\footrulewidth}{0pt}% % No footer rule
\setlength{\headheight}{34.2pt} % increase headheight

% Section/subsection/paragraph set-up
\RequirePackage[explicit]{titlesec}
\renewcommand{\thesubsection}{\Alph{subsection}}

\titleformat{\section}[runin]
{\sffamily\bfseries}
{}
{0em}
{\MakeUppercase{#1}.}
[]
\titleformat{\subsection}[runin]
{\sffamily\bfseries}
{}
{0em}
{#1.}
[]
\titleformat{\subsubsection}[runin]
{\sffamily\small\bfseries\itshape}
{}
{0em}
{#1}
[]    
\titleformat{\paragraph}[runin]
{\sffamily\small\bfseries}
{}
{0em}
{#1} 
\titlespacing*{\section}{0pc}{6pt \@plus1pt \@minus1pt}{5pt}
\titlespacing*{\subsection}{0pc}{3pt \@plus1pt \@minus0.75pt}{2pt}
\titlespacing*{\subsubsection}{0pc}{3pt \@plus1pt \@minus0.75pt}{2pt}
\titlespacing*{\paragraph}{0pc}{3pt \@plus1pt \@minus0.75pt}{2pt}


% Custom title page 
\renewcommand{\@maketitle}{%
{%
\vskip2pt%
{\raggedright \titlefont \@title\par}%
\vskip11pt
{\raggedright \@author\par}
\vskip11pt%
%\rule{\linewidth}{.4pt}
%\vskip12pt
}%
}%

% Other packages
\RequirePackage{enumitem} % For reducing bullet list item separation

% Math definitions
\renewcommand{\vec}[1]{\mathbf{#1}} % use bold vectors
